@@ -1,5 +1,5 @@
 /* AisleRiot - cscmi.h
- * Copyright (C) 1998 Jonathan Blandford <jrb@mit.edu>
+ * Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,6 +17,10 @@
  * USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "cscmi.h"
 #include "sol.h"
 #include "slot.h"
@@ -99,6 +103,23 @@ SCM make_card(hcard_type card)
 }
 
 /* Scheme functions */
+SCM scm_gettext(SCM message)
+{
+  static char * input = NULL;
+  char * output;
+  int len;
+
+  /* This is needed because we can't free the string before returning
+   * if it isn't translated. This way we have a permanent one-string
+   * memory leak and nothing more. */
+  if (!input)
+    free (input);
+  
+  input = gh_scm2newstr (message, &len);
+  output = gettext (input);
+  return gh_str02scm (output);
+}
+
 SCM scm_get_card_width() 
 {
   return gh_long2scm(get_card_width());
@@ -155,12 +176,24 @@ SCM scm_reset_surface()
   return SCM_EOL;
 }
 
-SCM scm_add_slot(SCM slot) 
+SCM gg_scm_add_slot(SCM slot) 
 {
   add_slot(slot);
   return SCM_EOL;
 }
 
+SCM scm_set_slot_y_expansion(SCM scm_slot_id, SCM new_exp_val)
+{
+  hslot_type slot = get_slot(gh_scm2int(scm_slot_id));
+  slot->dy = gh_scm2int(new_exp_val);
+}
+
+SCM scm_set_slot_x_expansion(SCM scm_slot_id, SCM new_exp_val)
+{
+  hslot_type slot = get_slot(gh_scm2int(scm_slot_id));
+  slot->dx = gh_scm2int(new_exp_val);
+}
+
 SCM scm_get_slot(SCM scm_slot_id) 
 {
   SCM cards = SCM_EOL;
@@ -217,7 +250,7 @@ SCM scm_set_lambda(SCM start_game_lambda,
 
 SCM scm_myrandom(SCM range) 
 {
-  return gh_long2scm(random()%SCM_INUM(range));
+  return gh_long2scm(g_random_int_range(0,SCM_INUM(range)));
 }
 
 SCM scm_get_score() 
@@ -266,9 +299,11 @@ void cscm_init ()
   gh_new_procedure1_0("set-statusbar-message", scm_set_statusbar_message);
   gh_new_procedure1_0("set-surface-layout", scm_set_surface_layout);
   gh_new_procedure0_0("reset-surface", scm_reset_surface);
-  gh_new_procedure1_0("add-slot", scm_add_slot);
+  gh_new_procedure1_0("add-slot", gg_scm_add_slot);
   gh_new_procedure1_0("get-slot", scm_get_slot);  
   gh_new_procedure2_0("set-cards-c!", scm_set_cards);
+  gh_new_procedure2_0("set-slot-y-expansion!", scm_set_slot_y_expansion);
+  gh_new_procedure2_0("set-slot-x-expansion!", scm_set_slot_x_expansion);
   gh_new_procedure("set-lambda", scm_set_lambda, 8, 0, 1);
   gh_new_procedure1_0("random", scm_myrandom);
   gh_new_procedure0_0("get-score", scm_get_score);  
@@ -276,5 +311,6 @@ void cscm_init ()
   gh_new_procedure0_0("get-timeout", scm_get_timeout);  
   gh_new_procedure1_0("set-timeout!", scm_set_timeout);
   gh_new_procedure1_0("add-to-score!", scm_add_to_score);
+  gh_new_procedure("gettext", scm_gettext, 1, 0, 0);
   eval_installed_file ("sol.scm");
 }
