@@ -103,7 +103,7 @@
 ;; Utilities for the homecells
 ;;
 
-;; homecell id which holds the suit.  #f if no such homecell exists.
+;; homecell id which holds the suit or an empty slot if there is no slot.
 (define (homecell-by-suit suit)
   (define (p? slot)
     (and (not (empty-slot? slot))
@@ -112,7 +112,7 @@
 	((p? homecell-2) homecell-2)
 	((p? homecell-3) homecell-3)
 	((p? homecell-4) homecell-4)
-	(else #f)))
+	(#t (any-empty-homecell))))
 
 ;; An empty homecell's id, if any
 (define (any-empty-homecell)
@@ -172,17 +172,33 @@
 ;;
 
 (define (move-to-homecell card-list homecell-id)
-  (and (= (length card-list) 1)
-       (let ((card (car card-list)))
-	 (if (empty-slot? homecell-id)
-	     ; Put an Ace into an empty homecell
-	     (and (eq? (get-value card) ace)
-		  (add-to-score! 1)
-		  (add-card! homecell-id card))
-	     ; Put a +1 card into the homecell, whose suit is same.
-	     (and (homecell-join? (car (get-cards homecell-id)) card)
-		  (add-to-score! 1)
-		  (add-card! homecell-id card))))))
+	(and
+		(= (length card-list) 1)
+		(move-card-to-homecell (car card-list) homecell-id)
+	)
+)
+
+(define (move-card-to-homecell card homecell-id)
+	(cond
+		; if the homecell is empty, we can add an ace to it.
+		((and
+			(empty-slot? homecell-id)
+			(eq? (get-value card) ace)
+			(add-to-score! 1)
+			(add-card! homecell-id card)
+			(update-auto (get-suit card) (get-value card)))
+		#t)
+		; Put a +1 card into the homecell, whose suit is same.
+		((and
+			(not (empty-slot? homecell-id))
+			(homecell-join? (car (get-cards homecell-id)) card)
+			(add-to-score! 1)
+			(add-card! homecell-id card)
+			(update-auto (get-suit card) (get-value card)))
+		#t)
+		(#t #f)
+	)
+)
 
 (define (move-to-field card-list field-id)
   (and (field-sequence? card-list)
@@ -194,14 +210,78 @@
 		  (add-cards! field-id card-list))))))
 
 (define (move-to-freecell card-list freecell-id)
-  (and (= (length card-list) 1)
-       (empty-slot? freecell-id)
-       (add-cards! freecell-id card-list)))
+	(and
+		(= (length card-list) 1)
+		(move-card-to-freecell (car card-list) freecell-id)
+	)
+)
+
+(define (move-card-to-freecell card freecell-id)
+	(and
+		(not (boolean? freecell-id))
+		(empty-slot? freecell-id)
+		(add-card! freecell-id card)
+	)
+)
 
 ;;
 ;; Auto move stuffs
 ;;
 
+(def-save-var highest-club 0)
+(def-save-var highest-diamond 0)
+(def-save-var highest-heart 0)
+(def-save-var highest-spade 0)
+
+(define (update-auto suit value)
+	(cond
+		((eq? suit club) (set! highest-club value))
+		((eq? suit diamond) (set! highest-diamond value))
+		((eq? suit heart) (set! highest-heart value))
+		((eq? suit spade) (set! highest-spade value))
+	)
+)
+
+(define (max-auto-red)
+	(min
+		(+ 2 (min highest-club highest-spade))
+		(+ 3 (min highest-diamond highest-heart))
+	)
+)
+
+(define (max-auto-black)
+	(min
+		(+ 2 (min highest-diamond highest-heart))
+		(+ 3 (min highest-club highest-spade))
+	)
+)
+
+(define (move-low-cards slot)
+	(and
+		(not (homecell? slot))
+		(not (empty-slot? slot))
+		(let ((card (get-top-card slot)))
+			(if (= (get-color card) red)
+				(and
+					(<= (get-value card) (max-auto-red))
+					(move-card-to-homecell card (homecell-by-suit (get-suit card)))
+					(remove-card slot)
+					(move-low-cards 0)
+				)
+				(and
+					(<= (get-value card) (max-auto-black))
+					(move-card-to-homecell card (homecell-by-suit (get-suit card)))
+					(remove-card slot)
+					(move-low-cards 0)
+				)
+			)
+		)
+	)
+	(if (< slot field-8)
+		(move-low-cards (+ 1 slot))
+		#t
+	)
+)
 
 ;;
 ;; Callbacks & Initialize the game
@@ -249,6 +329,10 @@
 
   (add-blank-slot)
   (deal-initial-setup)
+  (update-auto club 0)
+  (update-auto diamond 0)
+  (update-auto heart 0)
+  (update-auto spade 0)
   (list 8 3)
 )
 
@@ -258,25 +342,34 @@
 	((freecell?   slot) #t)))
 
 (define (button-released start-slot card-list end-slot)
-  (cond ((homecell? end-slot) (move-to-homecell card-list end-slot))
-	((field?    end-slot) (move-to-field    card-list end-slot))
-	((freecell? end-slot) (move-to-freecell card-list end-slot))))
+	(and
+		(not (= start-slot end-slot))
+		(cond
+			((homecell? end-slot) (move-to-homecell card-list end-slot))
+			((field?    end-slot) (move-to-field    card-list end-slot))
+			((freecell? end-slot) (move-to-freecell card-list end-slot))
+		)
+		(move-low-cards 0)
+	)
+)
   
 (define (button-clicked slot)
   ; (FIXME)
   #f)
 
 (define (button-double-clicked slot)
-  (and (field? slot)
-       (not (empty-slot? slot))
-       (let ((card (get-top-card slot)))
-	 (if (eq? (get-value card) ace)
-	     ; move the Ace to an empty homecell
-	     (begin (remove-card slot)
-		    (add-to-score! 1)
-		    (add-card! (any-empty-homecell) card))
-	     ; move if the same suit and -1 value card is in a homecell.
-	     #f))))
+	(and
+		(not (empty-slot? slot))
+		(let ((card (get-top-card slot)))
+			(and
+;				(move-card-to-homecell card (homecell-by-suit (get-suit card)))
+				(move-card-to-freecell card (any-empty-freecell))
+				(remove-card slot)
+				(move-low-cards 0)
+			)
+		)
+	)
+)
 
 ;; Condition for fail -- no more cards to move
 (define (game-over)
