@@ -1,5 +1,5 @@
 /* AisleRiot - menu.c
- * Copyright (C) 1998 Jonathan Blandford <jrb@alum.mit.edu>
+ * Copyright (C) 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #include "cscmi.h"
 #include "draw.h"
 #include "events.h"
-#include "scroll-menu.h"
 
 static GtkWidget *about = NULL;
 
@@ -71,6 +70,7 @@ about_destroy_callback (void)
  
 void help_about_callback ()
 {
+  GdkPixbuf *pixbuf = NULL;
   const gchar *authors[] = {
 	  N_("Main program:  Jonathan Blandford (jrb@redhat.com)"),
 	  N_("                      Felix Bellaby (felix@pooh.u-net.com)"),
@@ -90,7 +90,17 @@ void help_about_callback ()
   };
 
   const gchar *translator_credits = _("translator_credits");
+	char *filename = NULL;
 
+	filename = gnome_program_locate_file (NULL,
+		GNOME_FILE_DOMAIN_APP_PIXMAP,  ("gnome-aisleriot.png"),
+		TRUE, NULL);
+	if (filename != NULL)
+	{
+		pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+		g_free (filename);
+	}
+  
   {
 	int i=0;
 	while (authors[i] != NULL) { authors[i]=_(authors[i]); i++; }
@@ -108,7 +118,11 @@ void help_about_callback ()
 			    (const char **)authors,
 			    (const char **)documenters,
 			    strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			    NULL);
+			    pixbuf);
+	
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+        gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (app));
   g_signal_connect (GTK_OBJECT (about),
 		      "destroy",
 		      (GtkSignalFunc) about_destroy_callback,
@@ -151,13 +165,10 @@ GnomeUIInfo game_menu[] = {
 
   GNOMEUIINFO_MENU_NEW_GAME_ITEM(random_seed, NULL),
 
-  GNOMEUIINFO_ITEM (N_("New _game of..."), N_("Start a new game of a different variation"), NULL, NULL),
+  GNOMEUIINFO_ITEM_STOCK (N_("_Select..."), N_("Choose a different variation of solitaire"), show_select_game_dialog, GTK_STOCK_OPEN),
 
   GNOMEUIINFO_MENU_RESTART_GAME_ITEM(restart_game, NULL),
 
-  GNOMEUIINFO_ITEM_STOCK(N_("_Select..."), N_("Select a new game variation"),
-			 show_select_game_dialog, GTK_STOCK_OPEN),
-
   GNOMEUIINFO_SEPARATOR,
 
   GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(undo_callback, NULL),
@@ -215,40 +226,13 @@ GnomeUIInfo toolbar[] =
   GNOMEUIINFO_ITEM_STOCK(N_("Redo"), N_("Redo the last move"),
 			 redo_callback, GTK_STOCK_REDO),
 
-  GNOMEUIINFO_SEPARATOR,
-
-  GNOMEUIINFO_ITEM_STOCK(N_("Exit"), N_("Quit Aisleriot"),
-			 quit_app, GTK_STOCK_QUIT),
   GNOMEUIINFO_END
 };
 
 void create_menus ()
 {
-  int i;
-  GtkWidget *w;
-  GtkWidget *menu_item;
-  GtkWidget *menu;
   gnome_app_create_menus (GNOME_APP(app), top_menu);
   gnome_app_create_toolbar (GNOME_APP(app), toolbar);
-
-  /* Kids, don't try this at home */
-  menu_item = game_menu [1].widget;
-  menu = gtk_menu_new ();
-  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), menu);
-  w = gtk_tearoff_menu_item_new ();
-  gtk_widget_show(w);
-  gtk_menu_shell_append (GTK_MENU_SHELL(menu), w);
-
-  for(i = 0; i < n_games; i++) {
-    w = gtk_menu_item_new_with_label 
-      (game_file_to_name (game_dents[i]->d_name));
-    gtk_widget_show(w);
-    gtk_menu_shell_append (GTK_MENU_SHELL(menu), w);
-    g_signal_connect (GTK_OBJECT(w), "activate", 
-			(GtkSignalFunc) new_rules,
-			(gpointer) game_dents[i]->d_name);
-  }
-  gtk_widget_show_all (menu);
 }
 
 void install_menu_hints (GnomeApp *app)
