@@ -1,5 +1,5 @@
 /* AisleRiot - sol.c
- * Copyright (C) 1998, 2001 Jonathan Blandford <jrb@alum.mit.edu>
+ * Copyright (C) 1998, 2001, 2003 Jonathan Blandford <jrb@alum.mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,6 +54,11 @@ GdkPixmap        *surface;
 GdkPixmap        *moving_card_pixmap;
 GtkObject*       card_deck;
 GdkCardDeckOptions deck_options = NULL;
+gboolean         dont_save = FALSE; /* If the game is selected on the
+                                     * command line we assume that it is
+                                     * special and don't save the state.
+                                     * This is essential for Freecell
+                                     * emulation.*/
 
 guint            score;
 /* guint            game_seconds;*/
@@ -150,7 +155,7 @@ void eval_installed_file (char *file)
     GtkWidget *w = gtk_message_dialog_new (GTK_WINDOW(app),
                                        GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
+                                       GTK_BUTTONS_OK,
                                        message);
 
     gtk_dialog_run (GTK_DIALOG(w));
@@ -219,7 +224,8 @@ void new_game (gchar* file, guint *seedp )
     }
     game_name = game_file_to_name (file);
 
-    save_state (gnome_master_client ());
+    if (!dont_save)
+      save_state (gnome_master_client ());
 
     rules_help[0].label = game_name;
     rules_help[0].user_data = game_file_to_help_entry(file);
@@ -355,8 +361,32 @@ void create_sol_board ()
 		      GTK_SIGNAL_FUNC (button_press_event), NULL);
 }
 
-void quit_app (GtkWidget *app)
+gboolean quit_app (GtkMenuItem *menuitem)
 {
+  GtkWidget *box;
+  gint response;
+
+  if (!game_over) {
+    box = gtk_message_dialog_new (GTK_WINDOW (app),
+            GTK_DIALOG_MODAL,
+            GTK_MESSAGE_QUESTION,
+            GTK_BUTTONS_NONE,
+            _("Are you sure you want to quit Aisleriot?"));
+    gtk_dialog_add_buttons (GTK_DIALOG (box),
+            GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+            GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
+            NULL);
+
+    
+    gtk_dialog_set_default_response (GTK_DIALOG (box), GTK_RESPONSE_REJECT);
+
+    response = gtk_dialog_run (GTK_DIALOG (box));
+    gtk_widget_destroy (box);
+
+    if (response == GTK_RESPONSE_REJECT)
+        return TRUE;
+  }
+  
   gtk_widget_destroy (app);
   gtk_main_quit ();
 }
@@ -364,14 +394,14 @@ void quit_app (GtkWidget *app)
 void create_main_window ()
 {
   /* This is the prefix used to retrieve the state when NOT restarted: */
-  gchar* prefix = 
+  const gchar* prefix = 
     gnome_client_get_global_config_prefix (gnome_master_client ());
 
   app = gnome_app_new ("sol", _("Aisleriot"));
   /* Use "prefix" as the default config location ... */
   gnome_config_push_prefix (prefix);
   /* ... and use it for the menubar and toolbar aw well: */
-  GNOME_APP (app)->prefix = prefix;
+  GNOME_APP (app)->prefix = (gchar*)prefix;
 
   gtk_widget_realize (app);
 
@@ -462,7 +492,7 @@ void main_prog(int argc, char *argv[])
 static void
 retrieve_state (GnomeClient *client)
 {
-  gchar *prefix = gnome_client_get_config_prefix (client);
+  const gchar *prefix = gnome_client_get_config_prefix (client);
 
   gnome_config_push_prefix (prefix);
   start_game = gnome_config_get_string_with_default 
@@ -472,7 +502,7 @@ retrieve_state (GnomeClient *client)
 
 #ifdef GNOME_SESSION_BUG
   if (strcmp (prefix, gnome_client_get_global_config_prefix (client))) {
-    prefix = gnome_config_get_real_path (prefix);
+    gchar *prefix = gnome_config_get_real_path (prefix);
     prefix[ strlen (prefix) - 1] = '\0';
     unlink (prefix);
   }
@@ -541,6 +571,7 @@ int main (int argc, char *argv [])
   for (i = 0; i < n_games; i++) {
     gchar *game_name = game_file_to_name (game_dents[i]->d_name);
     if (!strcasecmp (variation, game_name)) {
+      dont_save = TRUE;
       start_game = g_strdup ((gchar*) game_dents[i]->d_name);
       g_free (game_name);
       break;
