@@ -34,6 +34,7 @@
 static GtkWidget *mfield;
 static GtkWidget *pref_dialog;
 static GtkWidget *rbutton;
+static GtkWidget *ralign;
 static GConfClient *conf_client;
 GtkWidget *window;
 GtkWidget *flabel;
@@ -111,7 +112,7 @@ void update_score_state ()
 {
         gchar **names = NULL;
         gfloat *scores = NULL;
-        time_t *scoretimes = NULL;
+       time_t *scoretimes = NULL;
 	gint top;
 	gchar buf[64];
 
@@ -154,17 +155,25 @@ void new_game(GtkWidget *widget, gpointer data)
 	gtk_minefield_restart(GTK_MINEFIELD(mfield));
 	set_flabel(GTK_MINEFIELD(mfield));
 
-	gtk_widget_hide (rbutton);
+	gtk_widget_hide (ralign);
 	gtk_widget_show (mfield);
 }
 
 void focus_out_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
+        GtkRequisition req;
+
 	if (GAMES_CLOCK(clk)->timer_id == -1)
 		return;
 
+        /* This is a complete abuse of the sizing system, but it seems to
+         * be the only way to keep the window the same size when we substitute
+         * the "Press to resume" button, but still allow it to resize when we 
+         * resize the field. */
+        gtk_widget_size_request (mfield, &req);
+        gtk_widget_set_size_request (ralign, req.width, req.height);
 	gtk_widget_hide (mfield);
-	gtk_widget_show (rbutton);
+	gtk_widget_show (ralign);
 
 	gtk_widget_grab_focus(rbutton);
 
@@ -173,7 +182,7 @@ void focus_out_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 
 void resume_game_cb (GtkButton *widget, gpointer data)
 {
-	gtk_widget_hide (rbutton);
+	gtk_widget_hide (ralign);
 	gtk_widget_show (mfield);
 
 	games_clock_start(GAMES_CLOCK(clk));
@@ -323,6 +332,10 @@ about(GtkWidget *widget, gpointer data)
 				 (const char **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
+	
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+	
 	g_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
 	gtk_window_set_transient_for(GTK_WINDOW (about), GTK_WINDOW (window));
@@ -361,7 +374,7 @@ gconf_key_change_cb (GConfClient *client, guint cnxn_id,
 		int i;
 		i = value ? gconf_value_get_int (value) : 40;
 		if (nmines != i) {
-			nmines = range (i, 1, xsize * ysize);
+			nmines = range (i, 1, xsize * ysize - 2);
 			gtk_minefield_set_mines(GTK_MINEFIELD(mfield), nmines, minesize);
 			new_game (mfield, NULL);
 		}
@@ -401,13 +414,28 @@ size_radio_callback(GtkWidget *widget, gpointer data)
 	gtk_widget_set_sensitive(cframe, fsc == 3);
 }
 
+void fix_nmines (int xsize, int ysize)
+{
+  int maxmines;
+
+  /* Fix up the maximum number of mines so that there is always at least two
+   * free spaces. It could in theory be left at one, but that gives an
+   * instant win situation. */
+  maxmines = xsize*ysize - 2;
+  if (nmines > maxmines) {
+    gconf_client_set_int (conf_client, KEY_NMINES, maxmines, NULL);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON(mentry), maxmines);
+  }
+  gtk_spin_button_set_range (GTK_SPIN_BUTTON(mentry), 1, maxmines);
+}
+
 static void
 xsize_spin_cb (GtkSpinButton *spin, gpointer data)
 {
 	int size = gtk_spin_button_get_value_as_int (spin);
 	gconf_client_set_int (conf_client, KEY_XSIZE,
 			      size, NULL);
-
+        fix_nmines(size,ysize);
 }
 
 static void
@@ -416,7 +444,7 @@ ysize_spin_cb (GtkSpinButton *spin, gpointer data)
 	int size = gtk_spin_button_get_value_as_int (spin);
 	gconf_client_set_int (conf_client, KEY_YSIZE,
 			      size, NULL);
-
+        fix_nmines(xsize,size);
 }
 
 static void
@@ -526,6 +554,20 @@ static void preferences_callback (GtkWidget *widget, gpointer data)
 	gtk_widget_show (table2);
 	gtk_table_set_row_spacings (GTK_TABLE (table2), GNOME_PAD);
 
+	label2 = gtk_label_new (_("Number of mines:"));
+	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
+	gtk_widget_show (label2);
+	gtk_table_attach (GTK_TABLE (table2), label2, 0, 1, 2, 3,
+			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+	/* TODO: fix this when gconfised correctly */
+	mentry = gtk_spin_button_new_with_range (1, XSIZE_MAX*YSIZE_MAX, 1);
+	g_signal_connect (GTK_OBJECT (mentry), "value-changed",
+			GTK_SIGNAL_FUNC (nmines_spin_cb), NULL);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON(mentry), nmines);
+	gtk_table_attach (GTK_TABLE (table2), mentry, 1, 2, 2, 3, GTK_FILL, GTK_EXPAND
+			| GTK_FILL, 0, 0);
+	gtk_widget_show (mentry);
+
 	label2 = gtk_label_new (_("Horizontal:"));
 	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 	gtk_widget_show (label2);
@@ -554,20 +596,6 @@ static void preferences_callback (GtkWidget *widget, gpointer data)
 			| GTK_FILL, 0, 0);
 	gtk_widget_show (yentry);
 
-	label2 = gtk_label_new (_("Number of mines:"));
-	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
-	gtk_widget_show (label2);
-	gtk_table_attach (GTK_TABLE (table2), label2, 0, 1, 2, 3,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	/* TODO: fix this when gconfised correctly */
-	mentry = gtk_spin_button_new_with_range (1, XSIZE_MAX*YSIZE_MAX, 1);
-	g_signal_connect (GTK_OBJECT (mentry), "value-changed",
-			GTK_SIGNAL_FUNC (nmines_spin_cb), NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(mentry), nmines);
-	gtk_table_attach (GTK_TABLE (table2), mentry, 1, 2, 2, 3, GTK_FILL, GTK_EXPAND
-			| GTK_FILL, 0, 0);
-	gtk_widget_show (mentry);
-
 	gtk_container_add (GTK_CONTAINER (cframe), table2);
 
 	gtk_table_attach (GTK_TABLE (table), cframe, 1, 2, 0, 1, GTK_EXPAND |
@@ -706,8 +734,8 @@ main (int argc, char *argv[])
 	GtkWidget *status_table;
 	GtkWidget *button_table;
         GtkWidget *align;
+        GtkWidget *box;        
         GtkWidget *label;
-	GtkWidget *box;
 	GnomeClient *client;
 
 	gnome_score_init("gnomine");
@@ -833,10 +861,13 @@ main (int argc, char *argv[])
 	mfield = gtk_minefield_new();
 	gtk_box_pack_start(GTK_BOX(box), mfield, TRUE, TRUE, 0);
 
+        ralign = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX(box), ralign, TRUE, TRUE, 0);
 	rbutton = gtk_button_new_with_label ("Press to resume");
 	g_signal_connect (GTK_OBJECT(rbutton), "clicked", 
 			    GTK_SIGNAL_FUNC (resume_game_cb), NULL);
-	gtk_box_pack_start(GTK_BOX(box), rbutton, TRUE, TRUE, 0);
+        gtk_container_add (GTK_CONTAINER(ralign), rbutton);
+        gtk_widget_show (rbutton);
 	gtk_widget_show (box);
 
         setup_mode(mfield, fsize);
