@@ -25,8 +25,7 @@
 #include <time.h>
 
 #define APPNAME "gnotravex"
-#define APPNAME_LONG "Gnome Tetravex"
-#define GNOTRAVEX_VERSION "0.20"
+#define APPNAME_LONG "GNOME Tetravex"
 
 #define TILE_SIZE 51
 
@@ -39,6 +38,9 @@
 #define UNUSED 1
 #define USED 0
 
+#define SPACE_WIDTH (CORNER*2 + GAP + SIZE*TILE_SIZE*2)
+#define SPACE_HEIGHT (CORNER*2 + SIZE*TILE_SIZE)
+
 GtkWidget *window;
 GtkWidget *statusbar;
 GtkWidget *space;
@@ -294,9 +296,23 @@ gint button_release_space(GtkWidget *widget, GdkEventButton *event){
   return FALSE;
 }
 
-gint button_motion_space(GtkWidget *widget, GdkEventButton *event){ 
+gint button_motion_space(GtkWidget *widget, GdkEventButton *event){
+  static gint x = -1, y = -1;
+  gint newx, newy;
+  
   if(button_down == 1){
-    gdk_window_move(mover.window,event->x-mover.xoff,event->y-mover.yoff);
+    /* This is convoluted but it minimises the number of gtk_window_clear
+     * calls that are made. This is important with remote X connections. */
+    newx = event->x - mover.xoff;
+    newy = event->y - mover.yoff;
+    gdk_window_move (mover.window, newx, newy);
+    if ((x < 0)
+        || (y < 0)
+        || (x > (SPACE_WIDTH - TILE_SIZE))
+        || (y > (SPACE_HEIGHT - TILE_SIZE)))
+      gdk_window_clear (mover.window);
+    x = newx;
+    y = newy;
   }
   return FALSE;
 }
@@ -425,6 +441,7 @@ int setup_mover(int x,int y,int status){
     gdk_window_move(mover.window,x - mover.xoff,y - mover.yoff);
     gui_draw_pixmap(mover.pixmap,xx,yy);
     gdk_window_show(mover.window);
+
     tiles[yy][xx].status = UNUSED;
     gui_draw_pixmap(buffer,xx,yy);
     return 1;
@@ -528,10 +545,21 @@ int game_over(){
   return 1;
 }
 
+void show_score_dialog(const gchar *level, gint pos)
+{
+  GtkWidget *dialog;
+
+  dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, level, pos);
+  if (dialog != NULL) {
+    gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window));
+    gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+  }
+}
+
 void score_cb(GtkWidget *widget, gpointer data){
   gchar level[5];
   sprintf(level,"%dx%d",SIZE,SIZE);
-  gnome_scores_display (_(APPNAME_LONG), APPNAME, level, 0);
+  show_score_dialog (level, 0);
 }
 
 void game_score(){
@@ -546,7 +574,7 @@ void game_score(){
   score = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
   pos = gnome_score_log(score,level,FALSE);
   update_score_state ();
-  gnome_scores_display (_(APPNAME_LONG), APPNAME, level, pos);
+  show_score_dialog (level, pos);
 }
 
 void update_score_state ()
@@ -604,8 +632,7 @@ void redraw_all(){
 void redraw_left(){
   int x,y;
   GdkRegion *region;
-  GdkRectangle rect ={x:CORNER, y:CORNER, width:TILE_SIZE*SIZE,
-		     height:TILE_SIZE*SIZE};
+  GdkRectangle rect ={CORNER, CORNER, TILE_SIZE*SIZE, TILE_SIZE*SIZE};
 
   region = gdk_region_rectangle(&rect);
 
@@ -622,7 +649,7 @@ void redraw_left(){
 void create_space(){
   space = gtk_drawing_area_new();
   gnome_app_set_contents(GNOME_APP(window),space);
-  gtk_drawing_area_size(GTK_DRAWING_AREA(space),CORNER*2 + GAP+ SIZE*TILE_SIZE*2,SIZE*TILE_SIZE + CORNER*2);
+  gtk_drawing_area_size(GTK_DRAWING_AREA(space), SPACE_WIDTH, SPACE_HEIGHT);
   gtk_widget_set_events(space, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK);
   gtk_widget_realize(space);
   
@@ -723,7 +750,7 @@ void new_board(int size){
     hint_moving = 0;
   }
 
-  srand(time(NULL)+myrand);
+  g_random_set_seed(time(NULL)+myrand);
 
   myrand += 17;
 
@@ -734,10 +761,10 @@ void new_board(int size){
   for(y=0;y<size;y++)
     for(x=size;x<size*2;x++){
       tiles[y][x].status = USED;
-      tiles[y][x].n = rand()%10;
-      tiles[y][x].s = rand()%10;
-      tiles[y][x].w = rand()%10;
-      tiles[y][x].e = rand()%10;
+      tiles[y][x].n = g_random_int()%10;
+      tiles[y][x].s = g_random_int()%10;
+      tiles[y][x].w = g_random_int()%10;
+      tiles[y][x].e = g_random_int()%10;
     }
 
   /* Sort */
@@ -757,10 +784,10 @@ void new_board(int size){
   j=0;
   do {
     for(i=0;i<size*size*size;i++){
-      x = rand() % size +size;
-      y = rand() % size;
-      x1 = rand() % size + size;
-      y1 = rand() % size;
+      x = g_random_int() % size +size;
+      y = g_random_int() % size;
+      x1 = g_random_int() % size + size;
+      y1 = g_random_int() % size;
       tmp = tiles[y1][x1];
       tiles[y1][x1] = tiles[y][x];
       tiles[y][x] = tmp;
@@ -1070,7 +1097,7 @@ void solve_cb(GtkWidget *widget, gpointer data){
 }
 
 void about_cb(GtkWidget *widget, gpointer data){
-  GtkWidget *about;
+  static GtkWidget *about = NULL;
   GdkPixbuf *pixbuf = NULL;
   
   const gchar *authors[] = { "Lars Rydlinge", NULL };
@@ -1080,6 +1107,10 @@ void about_cb(GtkWidget *widget, gpointer data){
   /* Translator credits */
   gchar *translator_credits = _("translator_credits");
 
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
   {
 	  char *filename = NULL;
 
@@ -1095,14 +1126,19 @@ void about_cb(GtkWidget *widget, gpointer data){
   }
 
   about = gnome_about_new(_(APPNAME_LONG), 
-			  GNOTRAVEX_VERSION, 
+			  VERSION, 
 			  "(C) 1998 Lars Rydlinge",
 			  _("Tetravex clone\n(Comments to: Lars.Rydlinge@HIG.SE)"), 
 			  (const char **)authors,
                           (const char **)documenters,
                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			  pixbuf);
+	
+  if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);	  
+  
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
+  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
   gtk_widget_show(about);
 }
 
