@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * GNOME-Mahjongg
  * (C) 1998-1999 the Free Software Foundation
@@ -24,6 +25,7 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <games-clock.h>
+#include <games-gconf.h>
 
 #include "mahjongg.h"
 #include "solubility.h"
@@ -668,7 +670,7 @@ mapset_changed_cb (GConfClient *client,
 		GTK_WINDOW (window),
 		GTK_DIALOG_MODAL,
 		GTK_MESSAGE_INFO,
-		GTK_BUTTONS_CLOSE,
+		GTK_BUTTONS_OK,
 		_("This new mapset will take effect when you start "
 		  "a new game, or when Mahjongg is restarted."));
 
@@ -1066,46 +1068,21 @@ you_won (void)
         gint pos;
         time_t seconds;
         gfloat score;
-        gchar *message;
-        gint response;
         GtkWidget *dialog;
-
+	
         game_over = GAME_WON;
 
         seconds = GAMES_CLOCK (chrono)->stopped;
 
         score = (seconds / 60) * 1.0 + (seconds % 60) / 100.0;
         if (pos = gnome_score_log (score, score_current_mapset, FALSE)) {
-                gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, pos);
-                message = g_strdup_printf
-			(_("Fantastic!  %.2f!\n"
-			   "You have reached #%d in the Top Ten.\n\n"
-			   "Another game?"), score, pos);
-        } else {
-                message = g_strdup_printf
-			(_("Great!\nYou made it in %.2f.\n\n"
-			   "Another game?"), score);
-	}
-
-	update_score_state ();
-       	
-       	dialog = gtk_message_dialog_new (
-		GTK_WINDOW (window),
-		GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-		GTK_MESSAGE_QUESTION,
-		GTK_BUTTONS_YES_NO,
-		message);
-
-       	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
-
-       	response = gtk_dialog_run (GTK_DIALOG (dialog));
-		
-       	gtk_widget_destroy (dialog);
-       	
-       	if (response == GTK_RESPONSE_YES) {
-		ensure_pause_off ();
-		new_game (TRUE);
-	}       	
+                dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, pos);
+		if (dialog != NULL) {
+			gtk_window_set_transient_for (GTK_WINDOW(dialog),
+						      GTK_WINDOW(window));
+			gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+		}
+        } 
 }
 
 static void
@@ -1118,149 +1095,154 @@ pref_dialog_response (GtkDialog *dialog, gint response, gpointer data)
 	colour_well = NULL;
 }
 
+GtkWidget *
+bold_frame (gchar * title)
+{
+	gchar *markup;
+	GtkWidget * frame;
+	
+	markup = g_strdup_printf ("<b>%s</b>",title);
+	frame = gtk_frame_new(markup);
+	g_free(markup);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget(GTK_FRAME(frame))), TRUE);
+	
+	return frame;
+}
+
 void
 properties_callback (GtkWidget *widget, gpointer data)
 {
-	GtkWidget *tmenu, *mmenu, *otmenu, *ommenu;
-	GtkWidget *l, *hb, *f, *fv, *cols, *col1, *col2;
+	GtkWidget *menu, *omenu;
+	GtkWidget *vbox, *frame, *table, *w, *label;
+	GtkSizeGroup *group;
 
 	if (pref_dialog) {
 		gtk_window_present (GTK_WINDOW (pref_dialog));
 		return;
 	}
 
-	pref_dialog = gtk_dialog_new_with_buttons (_("Mahjongg - Preferences"),
+	pref_dialog = gtk_dialog_new_with_buttons (_("Preferences"),
 			GTK_WINDOW (window),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			NULL);
 
+	gtk_window_set_resizable (GTK_WINDOW (pref_dialog), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (pref_dialog),
-					 GTK_RESPONSE_OK);
+					 GTK_RESPONSE_CLOSE);
 	g_signal_connect (G_OBJECT (pref_dialog), "response",
 			  G_CALLBACK(pref_dialog_response), NULL);
 
-        cols = gtk_hbox_new (FALSE, FALSE);
-        col1 = gtk_vbox_new (FALSE, FALSE);
-        col2 = gtk_vbox_new (FALSE, FALSE);
+	group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-	f = gtk_frame_new (_ ("Tiles"));
-	gtk_container_set_border_width (GTK_CONTAINER (f), 5);
-	gtk_box_pack_start_defaults (GTK_BOX(col1), f);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
 
-	fv = gtk_vbox_new (0, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (fv), 5);
-	gtk_container_add (GTK_CONTAINER (f), fv);
+	frame = bold_frame (_("Tiles"));
 
-	/* The Tile sub-menu */
-	otmenu = gtk_option_menu_new ();
-	tmenu = gtk_menu_new ();
-	fill_tile_menu (tmenu, "mahjongg", 1);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(otmenu), tmenu);
-
-	hb = gtk_hbox_new (FALSE, FALSE);
+	table = gtk_table_new (2, 2, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 	
-	l = gtk_label_new (_("Tile set:"));
-	    
-	gtk_box_pack_start_defaults (GTK_BOX(hb), l);
-	gtk_box_pack_start_defaults (GTK_BOX(hb), otmenu);
+	label = gtk_label_new (_("Tile Set"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_size_group_add_widget (group, label);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
 
-	gtk_box_pack_start_defaults (GTK_BOX(fv), hb);
+	omenu = gtk_option_menu_new ();
+	menu = gtk_menu_new ();
+	fill_tile_menu (menu, "mahjongg", 1);
+	gtk_option_menu_set_menu (GTK_OPTION_MENU(omenu), menu);
+	gtk_table_attach_defaults (GTK_TABLE (table), omenu, 1, 2, 0, 1);
 
-	/* The Tile Background sub-menu */
-	otmenu = gtk_option_menu_new ();
-	tmenu = gtk_menu_new ();
-	fill_tile_menu (tmenu, "mahjongg/bg", 0);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(otmenu), tmenu);
+	label = gtk_label_new (_("Tile Background"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_size_group_add_widget (group, label);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 1, 2);
 
-	hb = gtk_hbox_new (FALSE, FALSE);
+	omenu = gtk_option_menu_new ();
+	menu = gtk_menu_new ();
+	fill_tile_menu (menu, "mahjongg/bg", 0);
+	gtk_option_menu_set_menu (GTK_OPTION_MENU(omenu), menu);
+	gtk_table_attach_defaults (GTK_TABLE (table), omenu, 1, 2, 1, 2);
 
-	l = gtk_label_new (_("Tile background:"));
+	gtk_container_add(GTK_CONTAINER (frame), table);
+	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
-	gtk_box_pack_start_defaults (GTK_BOX(hb), l);
-	gtk_box_pack_start_defaults (GTK_BOX(hb), otmenu);
 
-	gtk_box_pack_start_defaults (GTK_BOX(fv), hb);
+	frame = bold_frame (_("Maps"));
 
-	/* The Map sub-menu */
-	ommenu = gtk_option_menu_new ();
-	mmenu = gtk_menu_new ();
-	fill_map_menu (mmenu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU(ommenu), mmenu);
-
-	f = gtk_frame_new (_ ("Maps"));
-	gtk_container_set_border_width (GTK_CONTAINER (f), 5);
-
-	hb = gtk_hbox_new (FALSE, FALSE);
-       	l = gtk_label_new (_("Select Map:"));
-	    
-	gtk_box_pack_start_defaults (GTK_BOX(hb), l);
-	gtk_box_pack_start_defaults (GTK_BOX(hb), ommenu);
-
-	fv = gtk_vbox_new (0, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (fv), 5);
+	table = gtk_table_new (1, 2, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 	
-	gtk_box_pack_start_defaults (GTK_BOX(fv), hb);
-	gtk_box_pack_start_defaults (GTK_BOX(col1), f);
-	gtk_container_add (GTK_CONTAINER (f), fv);
+	label = gtk_label_new (_("Select Map"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_size_group_add_widget (group, label);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
 
-	/* The colour */
-	f = gtk_frame_new (_ ("Colours"));
-	gtk_container_set_border_width (GTK_CONTAINER (f), 5);
+	omenu = gtk_option_menu_new ();
+	menu = gtk_menu_new ();
+	fill_map_menu (menu);
+	gtk_option_menu_set_menu (GTK_OPTION_MENU(omenu), menu);
+	gtk_table_attach_defaults (GTK_TABLE (table), omenu, 1, 2, 0, 1);
+
+	gtk_container_add(GTK_CONTAINER (frame), table);
+	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
+
+
+	frame = bold_frame (_("Colours"));
+
+	table = gtk_table_new (1, 2, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
+	
+	label = gtk_label_new (_("Background Color"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_size_group_add_widget (group, label);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 1, 0, 1);
 
-	hb = gtk_hbox_new (FALSE, FALSE);
-	l = gtk_label_new (_("Background:"));
-      	gtk_box_pack_start_defaults (GTK_BOX(hb), l);
 	{
 	  int ur,ug,ub ;
 
-	  colour_well  = gnome_color_picker_new();
+	  w  = gnome_color_picker_new();
 	  sscanf (backgnd.name, "#%02x%02x%02x", &ur,&ug,&ub);
-	  gnome_color_picker_set_i8 (GNOME_COLOR_PICKER(colour_well),
-			  ur, ug, ub, 0);
-	  g_signal_connect (G_OBJECT(colour_well), "color_set",
+	  gnome_color_picker_set_i8 (GNOME_COLOR_PICKER(w), ur, ug, ub, 0);
+	  g_signal_connect (G_OBJECT(w), "color_set",
 			    G_CALLBACK (bg_colour_callback), &backgnd.name);
 	}
-	gtk_box_pack_start_defaults (GTK_BOX(hb), colour_well);
+	gtk_table_attach_defaults (GTK_TABLE (table), w, 1, 2, 0, 1);
 
-	fv = gtk_vbox_new (0, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (fv), 5);
+	gtk_container_add(GTK_CONTAINER (frame), table);
+	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
-	gtk_box_pack_start_defaults (GTK_BOX(fv), hb);
-	gtk_box_pack_start_defaults (GTK_BOX(col2), f) ;
-	gtk_container_add (GTK_CONTAINER (f), fv);
+
+	frame = bold_frame (_("Warnings"));
+
+	table = gtk_vbox_new (FALSE, FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
+
+	w = gtk_check_button_new_with_label (_("Warn when tiles don't match"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), popup_warn);
+	g_signal_connect (G_OBJECT(w), "clicked", G_CALLBACK (popup_warn_callback), NULL);
+	gtk_box_pack_start_defaults (GTK_BOX (table), w);
+
+	w = gtk_check_button_new_with_label (_("Show confirmation dialogs"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(w), popup_confirm);
+	g_signal_connect (G_OBJECT(w), "clicked", G_CALLBACK (popup_confirm_callback), NULL);
+	gtk_box_pack_start_defaults (GTK_BOX(table), w);
 	
-	/* Warning submenu */
-  	f = gtk_frame_new (_ ("Warnings"));
-  	gtk_container_set_border_width (GTK_CONTAINER (f), 5); 
+	gtk_container_add(GTK_CONTAINER (frame), table);
+	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
-	fv = gtk_vbox_new (0,5);
-	gtk_container_set_border_width (GTK_CONTAINER (fv), 5);
+	gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(pref_dialog)->vbox), vbox);
 
-	warn_cb = gtk_check_button_new_with_label
-		(_("Warn when tiles don't match"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(warn_cb), popup_warn);
-	g_signal_connect (G_OBJECT(warn_cb), "clicked",
-			  G_CALLBACK (popup_warn_callback), NULL);
-	gtk_box_pack_start_defaults (GTK_BOX(fv), warn_cb);
-
-	confirm_cb = gtk_check_button_new_with_label
-		(_("Show confirmation dialogs"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(confirm_cb),
-			popup_confirm);
-	g_signal_connect (G_OBJECT(confirm_cb), "clicked",
-			  G_CALLBACK (popup_confirm_callback), NULL);
-	gtk_box_pack_start_defaults (GTK_BOX(fv), confirm_cb);
-
-	gtk_box_pack_start_defaults (GTK_BOX(col2), f) ;
-	gtk_container_add (GTK_CONTAINER (f), fv);
-
-        gtk_box_pack_start_defaults (GTK_BOX(cols), col1);
-        gtk_box_pack_start_defaults (GTK_BOX(cols), col2);
-        gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(pref_dialog)->vbox),
-			cols);
-
-        gtk_widget_show_all (pref_dialog);
+	g_object_unref (group);
+	gtk_widget_show_all (pref_dialog);
 }
 
 gint
@@ -1432,7 +1414,14 @@ void ensure_pause_off (void)
 void
 scores_callback (GtkWidget *widget, gpointer data)
 {
-        gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, 0);
+	GtkWidget *dialog;
+
+	dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, 0);
+	if (dialog != NULL) {
+		gtk_window_set_transient_for (GTK_WINDOW(dialog),
+					      GTK_WINDOW(window));
+		gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+	}
 }
 
 void
@@ -1630,6 +1619,7 @@ void
 select_game (GtkWidget *widget, gpointer data)
 {
 	GtkWidget *dialog, *entry, *label;
+	GtkWidget *box;
 	gint response;
 
 	dialog = gtk_dialog_new_with_buttons (_("Select Game"),
@@ -1642,12 +1632,19 @@ select_game (GtkWidget *widget, gpointer data)
 						 NULL);
 	
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	box = GTK_DIALOG (dialog)->vbox;
+
+	gtk_box_set_spacing (GTK_BOX (box), 8);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 8);
 
 	label = gtk_label_new (_("Game Number:"));
-	gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(dialog)->vbox), label);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_box_pack_start_defaults (GTK_BOX(box), label);
 	
 	entry = gtk_entry_new ();
-	gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(dialog)->vbox), entry);
+	gtk_box_pack_start_defaults (GTK_BOX(box), entry);
 	
 	gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 	gtk_window_set_focus (GTK_WINDOW (dialog), entry);
@@ -1656,12 +1653,13 @@ select_game (GtkWidget *widget, gpointer data)
 	
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	
-        if (response == GTK_RESPONSE_OK) {
+	if (response == GTK_RESPONSE_OK) {
 		next_seed = atoi (gtk_entry_get_text (GTK_ENTRY (entry)));
 		gtk_widget_destroy (dialog);
-                confirm_action (widget, (gpointer) NEW_GAME_WITH_SEED);
-        } else
+		confirm_action (widget, (gpointer) NEW_GAME_WITH_SEED);
+	} else {
               	gtk_widget_destroy (dialog);
+	}
 }
 
 void
@@ -1889,23 +1887,27 @@ create_mahjongg_board (GtkWidget *mbox)
 	set_backgnd_colour (buf) ;
 	g_free (buf);
 
-	buf = gconf_client_get_string (conf_client,
-			"/apps/mahjongg/tileset", NULL);
-        buf2 = gconf_client_get_string (conf_client,
-			"/apps/mahjongg/background", NULL);
+	buf = gconf_client_get_string (conf_client, "/apps/mahjongg/tileset", NULL);
+	if (buf == NULL) {
+		buf = g_strdup("default.png");
+	}
+	buf2 = gconf_client_get_string (conf_client, "/apps/mahjongg/background", NULL);
+	if (buf2 == NULL) {
+		buf2 = g_strdup("bg1.png");
+	}
         
 	popup_warn = gconf_client_get_bool (conf_client,
-			"/apps/mahjongg/warn", NULL);
-
+					    "/apps/mahjongg/warn", NULL);
+	
 	popup_confirm = gconf_client_get_bool (conf_client,
-			"/apps/mahjongg/confirm", NULL);
+					       "/apps/mahjongg/confirm", NULL);
 
 	do_game ();
 	load_tiles (buf, buf2);
 
 	create_canvas_items ();
 
-        g_free (buf2);
+	g_free (buf2);
 	g_free (buf);
 	init_game ();
 	update_score_state ();
@@ -2005,40 +2007,6 @@ shuffle_tiles_callback (GtkWidget *widget, gpointer data)
         }
 }
 
-static void 
-gconf_sanity_check(void)
-{
-  gchar *tileset;
-  GError *error = NULL;
-  
-  tileset = gconf_client_get_string (conf_client,
-                                     "/apps/mahjongg/tileset", &error);
-  if (error) {
-    GtkWidget *dialog;
-    dialog = gtk_message_dialog_new (NULL,
-                                     0,
-                                     GTK_MESSAGE_ERROR,
-                                     GTK_BUTTONS_CLOSE,
-                                     _("There was an error accessing GConf: %s"),
-                                     error->message);
-    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-    gtk_dialog_run(GTK_DIALOG(dialog));
-    exit(1);
-  } else if (!tileset) {
-    GtkWidget *dialog;
-    dialog = gtk_message_dialog_new (NULL,
-                                     0,
-                                     GTK_MESSAGE_ERROR,
-                                     GTK_BUTTONS_CLOSE,
-                                     _("The default configuration values could not be retrieved correctly. Please check your GConf configuration, specifically that the schemas are installed correctly"));
-    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-    gtk_dialog_run(GTK_DIALOG(dialog));
-    exit(1);
-  } else {
-    g_free (tileset);
-  }
-}
-
 int
 main (int argc, char *argv [])
 {
@@ -2046,9 +2014,9 @@ main (int argc, char *argv [])
 	GtkWidget *chrono_label;
 	GtkWidget *status_box;
 	GtkWidget *group_box;
-        gboolean show=TRUE;
+	gboolean show=TRUE;
 
-        gnome_score_init (APPNAME);
+	gnome_score_init (APPNAME);
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -2060,10 +2028,14 @@ main (int argc, char *argv [])
 			    GNOME_PARAM_APP_DATADIR, DATADIR,
 			    NULL);
 
-        gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-mahjongg.png");
-	new_seed ();
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-mahjongg.png");
+
 	conf_client = gconf_client_get_default ();
-	gconf_sanity_check();
+	if (!games_gconf_sanity_check_string (conf_client, "/apps/mahjongg/tileset")) {
+		return 1;
+	}
+
+	new_seed ();
 
 	window = gnome_app_new (APPNAME, _(APPNAME_LONG));
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
@@ -2109,7 +2081,7 @@ main (int argc, char *argv [])
 	gnome_app_create_menus (GNOME_APP (window), mainmenu);
 	gnome_app_install_menu_hints(GNOME_APP (window), mainmenu);
 
-        gnome_app_create_toolbar (GNOME_APP (window), toolbar_uiinfo);
+	gnome_app_create_toolbar (GNOME_APP (window), toolbar_uiinfo);
 
 	g_signal_connect (G_OBJECT (window), "delete_event",
 			  G_CALLBACK (delete_event_callback), (gpointer)QUIT_GAME);
@@ -2123,19 +2095,19 @@ main (int argc, char *argv [])
 	show = gconf_client_get_bool (conf_client,
 			"/apps/mahjongg/show-toolbar", NULL);
 
-        if (show) {
+	if (show) {
 		gtk_check_menu_item_set_active
 			(GTK_CHECK_MENU_ITEM(settingsmenu[0].widget), TRUE);
 	} else {
 		BonoboDockItem *gdi;
-
-                gtk_check_menu_item_set_active
+		
+		gtk_check_menu_item_set_active
 			(GTK_CHECK_MENU_ITEM(settingsmenu[0].widget), FALSE);
 		gdi = gnome_app_get_dock_item_by_name
 			(GNOME_APP (window), GNOME_APP_TOOLBAR_NAME);
-                gtk_widget_hide(GTK_WIDGET(gdi)) ;
-                gtk_widget_queue_resize (window);
-        }
+		gtk_widget_hide(GTK_WIDGET(gdi)) ;
+		gtk_widget_queue_resize (window);
+	}
 
 	init_config();
 
